@@ -23,8 +23,9 @@ from .operations import run
 from .environment import get_environment
 from .template import init
 from .util.misc import redirect_log
+from .operations import with_job
 
-__version__ = '0.6.3'
+__version__ = '0.6.4'
 
 __all__ = [
     'environment',
@@ -41,4 +42,5 @@ __all__ = [
     'init',
     'redirect_log',
     'get_environment',
+    'with_job'
     ]
